Troubleshooting
===============

This section contains information on how to fix the most common problems.

No SENTRY_DSN configured
************************

Define `SENTRY_DSN` in your `settings.py` or in `OS Environment<http://en.wikipedia.org/wiki/Operating_environment>`_.



